# Chatushka bot

Бот для чатиков (пока только для телеграмушки)


# Usage

## Installation

```shell
pip install chatushka
```

## Start bot

```shell
python -m chatushka --token <telegrambotapitoken>
```

## Test bot

- [x] добавить ботика в чат
- [x] делегировать боту админские права
- [x] написать в чатик /help

```shell
python -m chatushka --token <telegrambotapitoken>
```
